"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
var materialFileExtensionsToIcons = exports.materialFileExtensionsToIcons = {
  htm: "html",
  xhtml: "html",
  html_vm: "html",
  asp: "html",
  jade: "pug",
  pug: "pug",
  md: "markdown",
  markdown: "markdown",
  rst: "markdown",
  blink: "blink",
  css: "css",
  scss: "sass",
  sass: "sass",
  less: "less",
  json: "json",
  tsbuildinfo: "json",
  json5: "json",
  jsonl: "json",
  ndjson: "json",
  jinja: "jinja",
  jinja2: "jinja",
  j2: "jinja",
  "jinja-html": "jinja",
  "sublime-project": "sublime",
  "sublime-workspace": "sublime",
  tw: "twine",
  twee: "twine",
  yaml: "yaml",
  "YAML-tmLanguage": "yaml",
  yml: "yaml",
  xml: "xml",
  plist: "xml",
  xsd: "xml",
  dtd: "xml",
  xsl: "xml",
  xslt: "xml",
  resx: "xml",
  iml: "xml",
  xquery: "xml",
  tmLanguage: "xml",
  manifest: "xml",
  project: "xml",
  png: "image",
  jpeg: "image",
  jpg: "image",
  gif: "image",
  ico: "image",
  tif: "image",
  tiff: "image",
  psd: "image",
  psb: "image",
  ami: "image",
  apx: "image",
  bmp: "image",
  bpg: "image",
  brk: "image",
  cur: "image",
  dds: "image",
  dng: "image",
  exr: "image",
  fpx: "image",
  gbr: "image",
  img: "image",
  jbig2: "image",
  jb2: "image",
  jng: "image",
  jxr: "image",
  pbm: "image",
  pgf: "image",
  pic: "image",
  raw: "image",
  webp: "image",
  eps: "image",
  afphoto: "image",
  ase: "image",
  aseprite: "image",
  clip: "image",
  cpt: "image",
  heif: "image",
  heic: "image",
  kra: "image",
  mdp: "image",
  ora: "image",
  pdn: "image",
  reb: "image",
  sai: "image",
  tga: "image",
  xcf: "image",
  jfif: "image",
  js: "javascript",
  esx: "javascript",
  mjs: "javascript",
  jsx: "react",
  tsx: "react_ts",
  "routing.ts": "routing",
  "routing.tsx": "routing",
  "routing.js": "routing",
  "routing.jsx": "routing",
  "routes.ts": "routing",
  "routes.tsx": "routing",
  "routes.js": "routing",
  "routes.jsx": "routing",
  "action.js": "redux-action",
  "actions.js": "redux-action",
  "action.ts": "redux-action",
  "actions.ts": "ngrx-actions",
  "reducer.js": "redux-reducer",
  "reducers.js": "redux-reducer",
  "reducer.ts": "ngrx-reducer",
  "reducers.ts": "redux-reducer",
  "store.js": "vuex-store",
  "store.ts": "vuex-store",
  ini: "settings",
  dlc: "settings",
  dll: "settings",
  config: "settings",
  conf: "settings",
  properties: "settings",
  prop: "settings",
  settings: "settings",
  option: "settings",
  props: "settings",
  toml: "settings",
  prefs: "settings",
  "sln.dotsettings": "settings",
  "sln.dotsettings.user": "settings",
  cfg: "settings",
  ts: "typescript",
  "d.ts": "typescript-def",
  marko: "markojs",
  pdf: "pdf",
  xlsx: "table",
  xls: "table",
  csv: "table",
  tsv: "table",
  vscodeignore: "vscode",
  vsixmanifest: "vscode",
  vsix: "vscode",
  "code-workplace": "vscode",
  csproj: "visualstudio",
  ruleset: "visualstudio",
  sln: "visualstudio",
  suo: "visualstudio",
  vb: "visualstudio",
  vbs: "visualstudio",
  vcxitems: "visualstudio",
  "vcxitems.filters": "visualstudio",
  vcxproj: "visualstudio",
  "vcxproj.filters": "visualstudio",
  pdb: "database",
  sql: "database",
  pks: "database",
  pkb: "database",
  accdb: "database",
  mdb: "database",
  sqlite: "database",
  pgsql: "database",
  postgres: "database",
  psql: "database",
  db: "database",
  cs: "csharp",
  csx: "csharp",
  qs: "qsharp",
  zip: "zip",
  tar: "zip",
  gz: "zip",
  xz: "zip",
  br: "zip",
  bzip2: "zip",
  gzip: "zip",
  brotli: "zip",
  "7z": "zip",
  rar: "zip",
  tgz: "zip",
  vala: "vala",
  zig: "zig",
  exe: "exe",
  msi: "exe",
  java: "java",
  jar: "java",
  jsp: "java",
  c: "c",
  m: "c",
  i: "c",
  mi: "c",
  h: "h",
  cc: "cpp",
  cpp: "cpp",
  cxx: "cpp",
  "c++": "cpp",
  cp: "cpp",
  mm: "cpp",
  mii: "cpp",
  ii: "cpp",
  hh: "hpp",
  hpp: "hpp",
  hxx: "hpp",
  "h++": "hpp",
  hp: "hpp",
  tcc: "hpp",
  inl: "hpp",
  go: "go",
  py: "python",
  pyc: "python-misc",
  whl: "python-misc",
  url: "url",
  sh: "console",
  ksh: "console",
  csh: "console",
  tcsh: "console",
  zsh: "console",
  bash: "console",
  bat: "console",
  cmd: "console",
  awk: "console",
  fish: "console",
  exp: "console",
  ps1: "powershell",
  psm1: "powershell",
  psd1: "powershell",
  ps1xml: "powershell",
  psc1: "powershell",
  pssc: "powershell",
  gradle: "gradle",
  doc: "word",
  docx: "word",
  rtf: "word",
  cer: "certificate",
  cert: "certificate",
  crt: "certificate",
  pub: "key",
  key: "key",
  pem: "key",
  asc: "key",
  gpg: "key",
  passwd: "key",
  woff: "font",
  woff2: "font",
  ttf: "font",
  eot: "font",
  suit: "font",
  otf: "font",
  bmap: "font",
  fnt: "font",
  odttf: "font",
  ttc: "font",
  font: "font",
  fonts: "font",
  sui: "font",
  ntf: "font",
  mrf: "font",
  lib: "lib",
  bib: "lib",
  rb: "ruby",
  erb: "ruby",
  fs: "fsharp",
  fsx: "fsharp",
  fsi: "fsharp",
  fsproj: "fsharp",
  swift: "swift",
  ino: "arduino",
  dockerignore: "docker",
  dockerfile: "docker",
  tex: "tex",
  sty: "tex",
  dtx: "tex",
  ltx: "tex",
  pptx: "powerpoint",
  ppt: "powerpoint",
  pptm: "powerpoint",
  potx: "powerpoint",
  potm: "powerpoint",
  ppsx: "powerpoint",
  ppsm: "powerpoint",
  pps: "powerpoint",
  ppam: "powerpoint",
  ppa: "powerpoint",
  webm: "video",
  mkv: "video",
  flv: "video",
  vob: "video",
  ogv: "video",
  ogg: "video",
  gifv: "video",
  avi: "video",
  mov: "video",
  qt: "video",
  wmv: "video",
  yuv: "video",
  rm: "video",
  rmvb: "video",
  mp4: "video",
  m4v: "video",
  mpg: "video",
  mp2: "video",
  mpeg: "video",
  mpe: "video",
  mpv: "video",
  m2v: "video",
  vdi: "virtual",
  vbox: "virtual",
  "vbox-prev": "virtual",
  ics: "email",
  mp3: "audio",
  flac: "audio",
  m4a: "audio",
  wma: "audio",
  aiff: "audio",
  coffee: "coffee",
  cson: "coffee",
  iced: "coffee",
  txt: "document",
  graphql: "graphql",
  gql: "graphql",
  rs: "rust",
  raml: "raml",
  xaml: "xaml",
  hs: "haskell",
  kt: "kotlin",
  kts: "kotlin",
  patch: "git",
  lua: "lua",
  clj: "clojure",
  cljs: "clojure",
  cljc: "clojure",
  groovy: "groovy",
  r: "r",
  rmd: "r",
  dart: "dart",
  as: "actionscript",
  mxml: "mxml",
  ahk: "autohotkey",
  swf: "flash",
  swc: "swc",
  cmake: "cmake",
  asm: "assembly",
  a51: "assembly",
  inc: "assembly",
  nasm: "assembly",
  s: "assembly",
  ms: "assembly",
  agc: "assembly",
  ags: "assembly",
  aea: "assembly",
  argus: "assembly",
  mitigus: "assembly",
  binsource: "assembly",
  vue: "vue",
  ml: "ocaml",
  mli: "ocaml",
  cmx: "ocaml",
  "js.map": "javascript-map",
  "mjs.map": "javascript-map",
  "cjs.map": "javascript-map",
  "css.map": "css-map",
  lock: "lock",
  hbs: "handlebars",
  mustache: "handlebars",
  pm: "perl",
  raku: "perl",
  hx: "haxe",
  "spec.ts": "test-ts",
  "e2e-spec.ts": "test-ts",
  "test.ts": "test-ts",
  "ts.snap": "test-ts",
  "spec.tsx": "test-jsx",
  "test.tsx": "test-jsx",
  "tsx.snap": "test-jsx",
  "spec.jsx": "test-jsx",
  "test.jsx": "test-jsx",
  "jsx.snap": "test-jsx",
  "spec.js": "test-js",
  "e2e-spec.js": "test-js",
  "test.js": "test-js",
  "js.snap": "test-js",
  "module.ts": "nest-module",
  "module.js": "nest-module",
  "ng-template": "angular",
  "component.ts": "angular-component",
  "component.js": "angular-component",
  "guard.ts": "nest-guard",
  "guard.js": "nest-guard",
  "service.ts": "nest-service",
  "service.js": "nest-service",
  "pipe.ts": "nest-pipe",
  "pipe.js": "nest-pipe",
  "filter.js": "nest-filter",
  "directive.ts": "angular-directive",
  "directive.js": "angular-directive",
  "resolver.ts": "nest-resolver",
  "resolver.js": "nest-resolver",
  pp: "puppet",
  ex: "elixir",
  exs: "elixir",
  eex: "elixir",
  leex: "elixir",
  ls: "livescript",
  erl: "erlang",
  twig: "twig",
  jl: "julia",
  elm: "elm",
  pure: "purescript",
  purs: "purescript",
  tpl: "smarty",
  styl: "stylus",
  re: "reason",
  rei: "reason",
  cmj: "bucklescript",
  merlin: "merlin",
  v: "verilog",
  vhd: "verilog",
  sv: "verilog",
  svh: "verilog",
  nb: "mathematica",
  wl: "wolframlanguage",
  wls: "wolframlanguage",
  njk: "nunjucks",
  nunjucks: "nunjucks",
  robot: "robot",
  sol: "solidity",
  au3: "autoit",
  haml: "haml",
  yang: "yang",
  mjml: "mjml",
  tf: "terraform",
  "tf.json": "terraform",
  tfvars: "terraform",
  tfstate: "terraform",
  "blade.php": "laravel",
  "inky.php": "laravel",
  applescript: "applescript",
  ipa: "applescript",
  cake: "cake",
  feature: "cucumber",
  nim: "nim",
  nimble: "nim",
  apib: "apiblueprint",
  apiblueprint: "apiblueprint",
  riot: "riot",
  tag: "riot",
  vfl: "vfl",
  kl: "kl",
  pcss: "postcss",
  sss: "postcss",
  todo: "todo",
  cfml: "coldfusion",
  cfc: "coldfusion",
  lucee: "coldfusion",
  cfm: "coldfusion",
  cabal: "cabal",
  nix: "nix",
  slim: "slim",
  http: "http",
  rest: "http",
  rql: "restql",
  restql: "restql",
  kv: "kivy",
  graphcool: "graphcool",
  sbt: "sbt",
  apk: "android",
  env: "tune",
  "gitlab-ci.yml": "gitlab",
  jenkinsfile: "jenkins",
  jenkins: "jenkins",
  "rootReducer.ts": "ngrx-reducer",
  "state.ts": "ngrx-state",
  "effects.ts": "ngrx-effects",
  "selectors.ts": "ngrx-selectors",
  cr: "crystal",
  ecr: "crystal",
  "drone.yml": "drone",
  cu: "cuda",
  cuh: "cuda",
  log: "log",
  def: "dotjs",
  dot: "dotjs",
  jst: "dotjs",
  ejs: "ejs",
  ".wakatime-project": "wakatime",
  pde: "processing",
  "stories.js": "storybook",
  "stories.jsx": "storybook",
  "story.js": "storybook",
  "story.jsx": "storybook",
  "stories.ts": "storybook",
  "stories.tsx": "storybook",
  "story.ts": "storybook",
  "story.tsx": "storybook",
  wpy: "wepy",
  hcl: "hcl",
  san: "san",
  djt: "django",
  red: "red",
  fxp: "foxpro",
  prg: "foxpro",
  pot: "i18n",
  po: "i18n",
  mo: "i18n",
  wat: "webassembly",
  wasm: "webassembly",
  ipynb: "jupyter",
  d: "d",
  mdx: "mdx",
  bal: "ballerina",
  balx: "ballerina",
  rkt: "racket",
  bzl: "bazel",
  bazel: "bazel",
  mint: "mint",
  vm: "velocity",
  fhtml: "velocity",
  vtl: "velocity",
  gd: "godot",
  godot: "godot-assets",
  tres: "godot-assets",
  tscn: "godot-assets",
  "azure-pipelines.yml": "azure-pipelines",
  "azure-pipelines.yaml": "azure-pipelines",
  azcli: "azure",
  vagrantfile: "vagrant",
  prisma: "prisma",
  cshtml: "razor",
  vbhtml: "razor",
  abc: "abc",
  ad: "asciidoc",
  adoc: "asciidoc",
  asciidoc: "asciidoc",
  edge: "edge",
  ss: "scheme",
  scm: "scheme",
  lisp: "lisp",
  lsp: "lisp",
  cl: "lisp",
  fast: "lisp",
  stl: "3d",
  obj: "3d",
  ac: "3d",
  blend: "3d",
  mesh: "3d",
  mqo: "3d",
  pmd: "3d",
  pmx: "3d",
  skp: "3d",
  vac: "3d",
  vdp: "3d",
  vox: "3d",
  svg: "svg",
  svelte: "svelte",
  vimrc: "vim",
  gvimrc: "vim",
  exrc: "vim",
  vim: "vim",
  viminfo: "vim",
  "controller.ts": "nest-controller",
  "controller.js": "nest-controller",
  "middleware.ts": "nest-middleware",
  "middleware.js": "nest-middleware",
  "decorator.ts": "nest-decorator",
  "decorator.js": "nest-decorator",
  "filter.ts": "nest-filter",
  "gateway.ts": "nest-gateway",
  "gateway.js": "nest-gateway",
  moon: "moonscript",
  prw: "advpl_prw",
  prx: "advpl_prw",
  ptm: "advpl_ptm",
  tlpp: "advpl_tlpp",
  ch: "advpl_include",
  iso: "disc",
  f: "fortran",
  f77: "fortran",
  f90: "fortran",
  f95: "fortran",
  f03: "fortran",
  f08: "fortran",
  tcl: "tcl",
  liquid: "liquid",
  p: "prolog",
  pro: "prolog",
  coco: "coconut",
  sketch: "sketch",
  pwn: "pawn",
  amx: "pawn",
  "4th": "forth",
  fth: "forth",
  frt: "forth",
  iuml: "uml",
  pu: "uml",
  puml: "uml",
  plantuml: "uml",
  wsd: "uml",
  wrap: "meson",
  dhall: "dhall",
  dhallb: "dhall",
  sml: "sml",
  mlton: "sml",
  mlb: "sml",
  sig: "sml",
  fun: "sml",
  cm: "sml",
  lex: "sml",
  use: "sml",
  grm: "sml",
  opam: "opam",
  imba: "imba",
  drawio: "drawio",
  dio: "drawio",
  pas: "pascal",
  unity: "shaderlab",
  sas: "sas",
  sas7bdat: "sas",
  sashdat: "sas",
  astore: "sas",
  ast: "sas",
  sast: "sas",
  nupkg: "nuget",
  command: "command",
  dsc: "denizenscript",
  "code-search": "search",
  mcfunction: "minecraft",
  res: "rescript",
  resi: "rescript",
  b: "brainfuck",
  bf: "brainfuck",
  bicep: "bicep",
  cob: "cobol",
  cbl: "cobol",
  gr: "grain",
  lol: "lolcode",
  idr: "idris",
  ibc: "idris"
};

var materialFileNamesToIcons = exports.materialFileNamesToIcons = {
  file: "file",
  ".pug-lintrc": "pug",
  ".pug-lintrc.js": "pug",
  ".pug-lintrc.json": "pug",
  ".jscsrc": "json",
  ".jshintrc": "json",
  "composer.lock": "json",
  ".jsbeautifyrc": "json",
  ".esformatter": "json",
  "cdp.pid": "json",
  ".mjmlconfig": "json",
  ".htaccess": "xml",
  "router.js": "routing",
  "router.jsx": "routing",
  "router.ts": "routing",
  "router.tsx": "routing",
  "routes.js": "routing",
  "routes.jsx": "routing",
  "routes.ts": "routing",
  "routes.tsx": "routing",
  "action.js": "redux-action",
  "actions.js": "redux-action",
  "action.ts": "redux-action",
  "actions.ts": "redux-action",
  "reducer.js": "redux-reducer",
  "reducers.js": "redux-reducer",
  "reducer.ts": "redux-reducer",
  "reducers.ts": "redux-reducer",
  "store.js": "vuex-store",
  "store.ts": "vuex-store",
  ".jshintignore": "settings",
  ".buildignore": "settings",
  ".mrconfig": "settings",
  ".yardopts": "settings",
  "manifest.mf": "settings",
  ".clang-format": "settings",
  ".clang-tidy": "settings",
  "go.mod": "go-mod",
  "go.sum": "go-mod",
  "requirements.txt": "python-misc",
  pipfile: "python-misc",
  ".python-version": "python-misc",
  "manifest.in": "python-misc",
  pylintrc: "python-misc",
  ".pylintrc": "python-misc",
  "gradle.properties": "gradle",
  gradlew: "gradle",
  "gradle-wrapper.properties": "gradle",
  copying: "certificate",
  "copying.md": "certificate",
  "copying.txt": "certificate",
  license: "certificate",
  "license.md": "certificate",
  "license.txt": "certificate",
  licence: "certificate",
  "licence.md": "certificate",
  "licence.txt": "certificate",
  ".htpasswd": "key",
  gemfile: "gemfile",
  dockerfile: "docker",
  "dockerfile.prod": "docker",
  "dockerfile.production": "docker",
  "Dockerfile.alpha": "docker",
  "Dockerfile.beta": "docker",
  "Dockerfile.stage": "docker",
  "Dockerfile.staging": "docker",
  "Dockerfile.dev": "docker",
  "Dockerfile.development": "docker",
  "Dockerfile.test": "docker",
  "Dockerfile.testing": "docker",
  "Dockerfile.web": "docker",
  "Dockerfile.worker": "docker",
  "docker-compose.yml": "docker",
  "docker-compose.yaml": "docker",
  "docker-compose.dev.yml": "docker",
  "docker-compose.local.yml": "docker",
  "docker-compose.ci.yml": "docker",
  "docker-compose.override.yml": "docker",
  "docker-compose.staging.yml": "docker",
  "docker-compose.prod.yml": "docker",
  "docker-compose.production.yml": "docker",
  "docker-compose.test.yml": "docker",
  ".mailmap": "email",
  ".graphqlconfig": "graphql",
  ".gitignore": "git",
  ".gitconfig": "git",
  ".gitattributes": "git",
  ".gitmodules": "git",
  ".gitkeep": "git",
  "git-history": "git",
  ".luacheckrc": "lua",
  ".Rhistory": "r",
  "cmakelists.txt": "cmake",
  "cmakecache.txt": "cmake",
  "vue.config.js": "vue-config",
  "vue.config.ts": "vue-config",
  "nuxt.config.js": "nuxt",
  "nuxt.config.ts": "nuxt",
  "security.md": "lock",
  "security.txt": "lock",
  security: "lock",
  "angular-cli.json": "angular",
  ".angular-cli.json": "angular",
  "angular.json": "angular",
  "vercel.json": "vercel",
  ".vercelignore": "vercel",
  "now.json": "vercel",
  ".nowignore": "vercel",
  ".vfl": "vfl",
  ".kl": "kl",
  "postcss.config.js": "postcss",
  ".postcssrc.js": "postcss",
  ".postcssrc": "postcss",
  ".postcssrc.json": "postcss",
  ".postcssrc.yml": "postcss",
  "posthtml.config.js": "posthtml",
  ".posthtmlrc.js": "posthtml",
  ".posthtmlrc": "posthtml",
  ".posthtmlrc.json": "posthtml",
  ".posthtmlrc.yml": "posthtml",
  "cabal.project": "cabal",
  "cabal.project.freeze": "cabal",
  "cabal.project.local": "cabal",
  CNAME: "http",
  "project.graphcool": "graphcool",
  "webpack.js": "webpack",
  "webpack.ts": "webpack",
  "webpack.base.js": "webpack",
  "webpack.base.ts": "webpack",
  "webpack.config.js": "webpack",
  "webpack.config.ts": "webpack",
  "webpack.common.js": "webpack",
  "webpack.common.ts": "webpack",
  "webpack.config.common.js": "webpack",
  "webpack.config.common.ts": "webpack",
  "webpack.config.common.babel.js": "webpack",
  "webpack.config.common.babel.ts": "webpack",
  "webpack.dev.js": "webpack",
  "webpack.dev.ts": "webpack",
  "webpack.development.js": "webpack",
  "webpack.development.ts": "webpack",
  "webpack.config.dev.js": "webpack",
  "webpack.config.dev.ts": "webpack",
  "webpack.config.dev.babel.js": "webpack",
  "webpack.config.dev.babel.ts": "webpack",
  "webpack.prod.js": "webpack",
  "webpack.prod.ts": "webpack",
  "webpack.production.js": "webpack",
  "webpack.production.ts": "webpack",
  "webpack.server.js": "webpack",
  "webpack.server.ts": "webpack",
  "webpack.client.js": "webpack",
  "webpack.client.ts": "webpack",
  "webpack.config.server.js": "webpack",
  "webpack.config.server.ts": "webpack",
  "webpack.config.client.js": "webpack",
  "webpack.config.client.ts": "webpack",
  "webpack.config.production.babel.js": "webpack",
  "webpack.config.production.babel.ts": "webpack",
  "webpack.config.prod.babel.js": "webpack",
  "webpack.config.prod.babel.ts": "webpack",
  "webpack.config.prod.js": "webpack",
  "webpack.config.prod.ts": "webpack",
  "webpack.config.production.js": "webpack",
  "webpack.config.production.ts": "webpack",
  "webpack.config.staging.js": "webpack",
  "webpack.config.staging.ts": "webpack",
  "webpack.config.babel.js": "webpack",
  "webpack.config.babel.ts": "webpack",
  "webpack.config.base.babel.js": "webpack",
  "webpack.config.base.babel.ts": "webpack",
  "webpack.config.base.js": "webpack",
  "webpack.config.base.ts": "webpack",
  "webpack.config.staging.babel.js": "webpack",
  "webpack.config.staging.babel.ts": "webpack",
  "webpack.config.coffee": "webpack",
  "webpack.config.test.js": "webpack",
  "webpack.config.test.ts": "webpack",
  "webpack.config.vendor.js": "webpack",
  "webpack.config.vendor.ts": "webpack",
  "webpack.config.vendor.production.js": "webpack",
  "webpack.config.vendor.production.ts": "webpack",
  "webpack.test.js": "webpack",
  "webpack.test.ts": "webpack",
  "webpack.dist.js": "webpack",
  "webpack.dist.ts": "webpack",
  "webpackfile.js": "webpack",
  "webpackfile.ts": "webpack",
  "ionic.config.json": "ionic",
  ".io-config.json": "ionic",
  "gulpfile.js": "gulp",
  "gulpfile.mjs": "gulp",
  "gulpfile.ts": "gulp",
  "gulpfile.babel.js": "gulp",
  "package.json": "nodejs",
  "package-lock.json": "nodejs",
  ".nvmrc": "nodejs",
  ".esmrc": "nodejs",
  ".node-version": "nodejs",
  ".npmignore": "npm",
  ".npmrc": "npm",
  ".yarnrc": "yarn",
  "yarn.lock": "yarn",
  ".yarnclean": "yarn",
  ".yarn-integrity": "yarn",
  "yarn-error.log": "yarn",
  ".yarnrc.yml": "yarn",
  ".yarnrc.yaml": "yarn",
  "androidmanifest.xml": "android",
  ".env.defaults": "tune",
  ".env.example": "tune",
  ".env.sample": "tune",
  ".env.schema": "tune",
  ".env.local": "tune",
  ".env.dev": "tune",
  ".env.development": "tune",
  ".env.qa": "tune",
  ".env.prod": "tune",
  ".env.production": "tune",
  ".env.staging": "tune",
  ".env.preview": "tune",
  ".env.test": "tune",
  ".env.testing": "tune",
  ".env.development.local": "tune",
  ".env.qa.local": "tune",
  ".env.production.local": "tune",
  ".env.staging.local": "tune",
  ".env.test.local": "tune",
  ".babelrc": "babel",
  ".babelrc.js": "babel",
  ".babelrc.json": "babel",
  "babel.config.json": "babel",
  "babel.config.js": "babel",
  "contributing.md": "contributing",
  "readme.md": "readme",
  "readme.txt": "readme",
  readme: "readme",
  changelog: "changelog",
  "changelog.md": "changelog",
  "changelog.txt": "changelog",
  changes: "changelog",
  "changes.md": "changelog",
  "changes.txt": "changelog",
  credits: "credits",
  "credits.txt": "credits",
  "credits.md": "credits",
  authors: "authors",
  "authors.md": "authors",
  "authors.txt": "authors",
  ".flowconfig": "flow",
  "favicon.ico": "favicon",
  "karma.conf.js": "karma",
  "karma.conf.ts": "karma",
  "karma.conf.coffee": "karma",
  "karma.config.js": "karma",
  "karma.config.ts": "karma",
  "karma-main.js": "karma",
  "karma-main.ts": "karma",
  ".bithoundrc": "bithound",
  ".appveyor.yml": "appveyor",
  "appveyor.yml": "appveyor",
  ".travis.yml": "travis",
  ".codecov.yml": "codecov",
  "codecov.yml": "codecov",
  "protractor.conf.js": "protractor",
  "protractor.conf.ts": "protractor",
  "protractor.conf.coffee": "protractor",
  "protractor.config.js": "protractor",
  "protractor.config.ts": "protractor",
  "fuse.js": "fusebox",
  procfile: "heroku",
  "procfile.windows": "heroku",
  ".editorconfig": "editorconfig",
  ".bowerrc": "bower",
  "bower.json": "bower",
  ".eslintrc.js": "eslint",
  ".eslintrc.cjs": "eslint",
  ".eslintrc.yaml": "eslint",
  ".eslintrc.yml": "eslint",
  ".eslintrc.json": "eslint",
  ".eslintrc": "eslint",
  ".eslintignore": "eslint",
  ".eslintcache": "eslint",
  "code_of_conduct.md": "conduct",
  "code_of_conduct.txt": "conduct",
  ".watchmanconfig": "watchman",
  "aurelia.json": "aurelia",
  "mocha.opts": "mocha",
  ".mocharc.yml": "mocha",
  ".mocharc.yaml": "mocha",
  ".mocharc.js": "mocha",
  ".mocharc.json": "mocha",
  ".mocharc.jsonc": "mocha",
  jenkinsfile: "jenkins",
  "firebase.json": "firebase",
  ".firebaserc": "firebase",
  "firestore.rules": "firebase",
  "firestore.indexes.json": "firebase",
  "rollup.config.js": "rollup",
  "rollup.config.ts": "rollup",
  "rollup-config.js": "rollup",
  "rollup-config.ts": "rollup",
  "rollup.config.common.js": "rollup",
  "rollup.config.common.ts": "rollup",
  "rollup.config.base.js": "rollup",
  "rollup.config.base.ts": "rollup",
  "rollup.config.prod.js": "rollup",
  "rollup.config.prod.ts": "rollup",
  "rollup.config.dev.js": "rollup",
  "rollup.config.dev.ts": "rollup",
  "rollup.config.prod.vendor.js": "rollup",
  "rollup.config.prod.vendor.ts": "rollup",
  ".hhconfig": "hack",
  ".stylelintrc": "stylelint",
  "stylelint.config.js": "stylelint",
  ".stylelintrc.json": "stylelint",
  ".stylelintrc.yaml": "stylelint",
  ".stylelintrc.yml": "stylelint",
  ".stylelintrc.js": "stylelint",
  ".stylelintignore": "stylelint",
  ".codeclimate.yml": "code-climate",
  ".prettierrc": "prettier",
  "prettier.config.js": "prettier",
  ".prettierrc.js": "prettier",
  ".prettierrc.json": "prettier",
  ".prettierrc.yaml": "prettier",
  ".prettierrc.yml": "prettier",
  ".prettierignore": "prettier",
  "apollo.config.js": "apollo",
  "nodemon.json": "nodemon",
  "nodemon-debug.json": "nodemon",
  ".entity": "ngrx-entity",
  ".hintrc": "webhint",
  browserslist: "browserlist",
  ".browserslistrc": "browserlist",
  ".snyk": "snyk",
  ".drone.yml": "drone",
  ".sequelizerc": "sequelize",
  "gatsby.config.js": "gatsby",
  "gatsby-config.js": "gatsby",
  "gatsby-node.js": "gatsby",
  "gatsby-browser.js": "gatsby",
  "gatsby-ssr.js": "gatsby",
  ".wakatime-project": "wakatime",
  "circle.yml": "circleci",
  ".cfignore": "cloudfoundry",
  "gruntfile.js": "grunt",
  "gruntfile.ts": "grunt",
  "gruntfile.coffee": "grunt",
  "gruntfile.babel.js": "grunt",
  "gruntfile.babel.ts": "grunt",
  "gruntfile.babel.coffee": "grunt",
  "jest.config.js": "jest",
  "jest.config.ts": "jest",
  "jest.config.cjs": "jest",
  "jest.config.mjs": "jest",
  "jest.config.json": "jest",
  "jest.e2e.config.js": "jest",
  "jest.e2e.config.ts": "jest",
  "jest.e2e.config.cjs": "jest",
  "jest.e2e.config.mjs": "jest",
  "jest.e2e.config.json": "jest",
  "jest.setup.js": "jest",
  "jest.setup.ts": "jest",
  "jest.json": "jest",
  ".jestrc": "jest",
  ".jestrc.js": "jest",
  ".jestrc.json": "jest",
  "jest.teardown.js": "jest",
  fastfile: "fastlane",
  appfile: "fastlane",
  ".helmignore": "helm",
  "wallaby.js": "wallaby",
  "wallaby.conf.js": "wallaby",
  "stencil.config.js": "stencil",
  "stencil.config.ts": "stencil",
  makefile: "makefile",
  ".releaserc": "semantic-release",
  ".releaserc.yaml": "semantic-release",
  ".releaserc.yml": "semantic-release",
  ".releaserc.json": "semantic-release",
  ".releaserc.js": "semantic-release",
  "release.config.js": "semantic-release",
  "bitbucket-pipelines.yaml": "bitbucket",
  "bitbucket-pipelines.yml": "bitbucket",
  ".bazelignore": "bazel",
  ".bazelrc": "bazel",
  "azure-pipelines.yml": "azure-pipelines",
  "azure-pipelines.yaml": "azure-pipelines",
  vagrantfile: "vagrant",
  "prisma.yml": "prisma",
  ".nycrc": "istanbul",
  ".nycrc.json": "istanbul",
  "tailwind.js": "tailwindcss",
  "tailwind.config.js": "tailwindcss",
  "buildkite.yml": "buildkite",
  "buildkite.yaml": "buildkite",
  "netlify.json": "netlify",
  "netlify.yml": "netlify",
  "netlify.yaml": "netlify",
  "netlify.toml": "netlify",
  "svelte.config.js": "svelte",
  "nest-cli.json": "nest",
  ".nest-cli.json": "nest",
  "nestconfig.json": "nest",
  ".nestconfig.json": "nest",
  ".percy.yml": "percy",
  ".gitpod.yml": "gitpod",
  codeowners: "codeowners",
  ".gcloudignore": "gcp",
  ".huskyrc": "husky",
  "husky.config.js": "husky",
  ".huskyrc.json": "husky",
  ".huskyrc.js": "husky",
  ".huskyrc.yaml": "husky",
  ".huskyrc.yml": "husky",
  tiltfile: "tilt",
  "capacitor.config.json": "capacitor",
  ".adonisrc.json": "adonis",
  ace: "adonis",
  "meson.build": "meson",
  "meson_options.txt": "meson",
  ".commitlintrc": "commitlint",
  ".commitlintrc.js": "commitlint",
  "commitlint.config.js": "commitlint",
  ".commitlintrc.json": "commitlint",
  ".commitlint.yaml": "commitlint",
  ".commitlint.yml": "commitlint",
  ".commitlintrc.yaml": "commitlint",
  ".commitlintrc.yml": "commitlint",
  ".buckconfig": "buck",
  "nx.json": "nrwl",
  dune: "dune",
  "dune-project": "dune",
  "dune-workspace": "dune",
  "dune-workspace.dev": "dune",
  "roadmap.md": "roadmap",
  "roadmap.txt": "roadmap",
  "timeline.md": "roadmap",
  "timeline.txt": "roadmap",
  "milestones.md": "roadmap",
  "milestones.txt": "roadmap",
  "nuget.config": "nuget",
  ".nuspec": "nuget",
  "nuget.exe": "nuget",
  "stryker.conf.js": "stryker",
  "stryker.conf.json": "stryker",
  ".modernizrrc": "modernizr",
  ".modernizrrc.js": "modernizr",
  ".modernizrrc.json": "modernizr",
  ".slugignore": "slug",
  "stitches.config.js": "stitches",
  "stitches.config.ts": "stitches",
  "nginx.conf": "nginx",
  ".replit": "replit",
  "snowpack.config.cjs": "snowpack",
  "snowpack.config.js": "snowpack",
  "snowpack.config.ts": "snowpack",
  "snowpack.config.json": "snowpack"
};